# coding: utf8
from __future__ import unicode_literals


ADJECTIVE_RULES = [
	["e", ""],			#pene -> pen
	["ere", ""],		#penere -> pen
	["est", ""],		#penest -> pen
	["este", ""]		#peneste -> pen
]


NOUN_RULES = [
	["en", "e"],		#hansken -> hanske
	["a", "e"],			#veska -> veske
	["et", ""],			#dyret -> dyr
	["er", "e"],		#hasker -> hanske	
	["ene", "e"]		#veskene -> veske
]


VERB_RULES = [
    ["er", "e"],		#vasker -> vaske
    ["et", "e"],		#vasket -> vaske
    ["es", "e"],		#vaskes -> vaske
    ["te", "e"],		#stekte -> steke
    ["år", "å"]			#får -> få
]


PUNCT_RULES = []



# coding: utf-8
from __future__ import unicode_literals

from ..util import make_tempdir
from ...language import Language

import pytest


@pytest.fixture
def meta_data():
    return {
        'name': 'name-in-fixture',
        'version': 'version-in-fixture',
        'description': 'description-in-fixture',
        'author': 'author-in-fixture',
        'email': 'email-in-fixture',
        'url': 'url-in-fixture',
        'license': 'license-in-fixture',
        'vectors': {'width': 0, 'vectors': 0, 'keys': 0, 'name': None}
    }


def test_serialize_language_meta_disk(meta_data):
    language = Language(meta=meta_data)
    with make_tempdir() as d:
        language.to_disk(d)
        new_language = Language().from_disk(d)
    assert new_language.meta == language.meta



# coding: utf8
from __future__ import unicode_literals

from .stop_words import STOP_WORDS
from .lex_attrs import LEX_ATTRS
from .tag_map import TAG_MAP

from ..tokenizer_exceptions import BASE_EXCEPTIONS
from ..norm_exceptions import BASE_NORMS
from ...language import Language
from ...attrs import LANG, NORM
from ...util import update_exc, add_lookups


class DutchDefaults(Language.Defaults):
    lex_attr_getters = dict(Language.Defaults.lex_attr_getters)
    lex_attr_getters.update(LEX_ATTRS)
    lex_attr_getters[LANG] = lambda text: 'nl'
    lex_attr_getters[NORM] = add_lookups(Language.Defaults.lex_attr_getters[NORM], BASE_NORMS)
    tokenizer_exceptions = update_exc(BASE_EXCEPTIONS)
    stop_words = STOP_WORDS
    tag_map = TAG_MAP


class Dutch(Language):
    lang = 'nl'
    Defaults = DutchDefaults


__all__ = ['Dutch']



'''Ensure vectors.resize() doesn't try to modify dictionary during iteration.'''
from __future__ import unicode_literals

from ...vectors import Vectors


def test_issue1539():
    v = Vectors(shape=(10, 10), keys=[5,3,98,100])
    v.resize((100,100))




# -*- coding: utf-8 -*-

from __future__ import unicode_literals

from ...attrs import LIKE_NUM

_num_words = ['μηδέν', 'ένας', 'δυο', 'δυό', 'τρεις', 'τέσσερις', 'πέντε', 'έξι', 'εφτά', 'επτά', 'οκτώ', 'οχτώ',
              'εννιά', 'εννέα', 'δέκα', 'έντεκα', 'ένδεκα', 'δώδεκα', 'δεκατρείς', 'δεκατέσσερις', 'δεκαπέντε',
              'δεκαέξι', 'δεκαεπτά', 'δεκαοχτώ', 'δεκαεννέα', 'δεκαεννεα', 'είκοσι', 'τριάντα', 'σαράντα', 'πενήντα',
              'εξήντα', 'εβδομήντα', 'ογδόντα', 'ενενήντα', 'εκατό', 'διακόσιοι', 'διακόσοι', 'τριακόσιοι', 'τριακόσοι',
              'τετρακόσιοι', 'τετρακόσοι', 'πεντακόσιοι', 'πεντακόσοι', 'εξακόσιοι', 'εξακόσοι', 'εφτακόσιοι',
              'εφτακόσοι', 'επτακόσιοι', 'επτακόσοι', 'οχτακόσιοι', 'οχτακόσοι', 'οκτακόσιοι', 'οκτακόσοι',
              'εννιακόσιοι', 'χίλιοι', 'χιλιάδα', 'εκατομμύριο', 'δισεκατομμύριο', 'τρισεκατομμύριο', 'τετράκις',
              'πεντάκις', 'εξάκις', 'επτάκις', 'οκτάκις', 'εννεάκις', 'ένα', 'δύο', 'τρία', 'τέσσερα', 'δις', 'χιλιάδες']


def like_num(text):
    text = text.replace(',', '').replace('.', '')
    if text.isdigit():
        return True
    if text.count('/') == 1:
        num, denom = text.split('/')
        if num.isdigit() and denom.isdigit():
            return True
    if text.count('^') == 1:
        num, denom = text.split('^')
        if num.isdigit() and denom.isdigit():
            return True
    if text.lower() in _num_words or text.lower().split(' ')[0] in _num_words:
        return True
    if text in _num_words:
        return True
    return False


LEX_ATTRS = {
    LIKE_NUM: like_num
}



# coding: utf8
from __future__ import unicode_literals


"""
Example sentences to test spaCy and its language models.

>>> from spacy.lang.de.examples import sentences
>>> docs = nlp.pipe(sentences)
"""


sentences = [
    "Die ganze Stadt ist ein Startup: Shenzhen ist das Silicon Valley für Hardware-Firmen",
    "Wie deutsche Startups die Technologie vorantreiben wollen: Künstliche Intelligenz",
    "Trend zum Urlaub in Deutschland beschert Gastwirten mehr Umsatz",
    "Bundesanwaltschaft erhebt Anklage gegen mutmaßlichen Schweizer Spion",
    "San Francisco erwägt Verbot von Lieferrobotern",
    "Autonome Fahrzeuge verlagern Haftpflicht auf Hersteller",
    "Wo bist du?",
    "Was ist die Hauptstadt von Deutschland?"
]



# coding: utf-8
from __future__ import unicode_literals

import pytest


def test_issue351(en_tokenizer):
    doc = en_tokenizer("   This is a cat.")
    assert doc[0].idx == 0
    assert len(doc[0]) == 3
    assert doc[1].idx == 3



# coding: utf-8
from __future__ import unicode_literals

import pytest


@pytest.mark.parametrize('string,lemma', [('câini', 'câine'),
                                          ('expedițiilor', 'expediție'),
                                          ('pensete', 'pensetă'),
                                          ('erau', 'fi')])
def test_lemmatizer_lookup_assigns(ro_tokenizer, string, lemma):
    tokens = ro_tokenizer(string)
    assert tokens[0].lemma_ == lemma



# coding: utf8
from __future__ import unicode_literals

from ..char_classes import ALPHA, ALPHA_LOWER, ALPHA_UPPER, QUOTES, HYPHENS
from ..char_classes import LIST_ELLIPSES, LIST_ICONS

_hyphens_no_dash = HYPHENS.replace('-', '').strip('|').replace('||', '')
_infixes = (LIST_ELLIPSES + LIST_ICONS +
            [r'(?<=[{}])\.(?=[{}])'.format(ALPHA_LOWER, ALPHA_UPPER),
             r'(?<=[{a}])[,!?/\(\)]+(?=[{a}])'.format(a=ALPHA),
             r'(?<=[{a}{q}])[:<>=](?=[{a}])'.format(a=ALPHA, q=QUOTES),
             r'(?<=[{a}])--(?=[{a}])'.format(a=ALPHA),
             r'(?<=[{a}]),(?=[{a}])'.format(a=ALPHA),
             r'(?<=[{a}])([{q}\)\]\(\[])(?=[\-{a}])'.format(a=ALPHA, q=QUOTES),
             r'(?<=[{a}])[?";:=,.]*(?:{h})(?=[{a}])'.format(a=ALPHA,
                                                            h=_hyphens_no_dash),
             r'(?<=[0-9])-(?=[0-9])'])

TOKENIZER_INFIXES = _infixes



from __future__ import unicode_literals, print_function
import pytest

from spacy.attrs import LOWER
from spacy.matcher import Matcher


@pytest.mark.models('en')
def test_en_ner_simple_types(EN):
    tokens = EN(u'Mr. Best flew to New York on Saturday morning.')
    ents = list(tokens.ents)
    assert ents[0].start == 1
    assert ents[0].end == 2
    assert ents[0].label_ == 'PERSON'
    assert ents[1].start == 4
    assert ents[1].end == 6
    assert ents[1].label_ == 'GPE'


@pytest.mark.skip
@pytest.mark.models('en')
def test_en_ner_consistency_bug(EN):
    '''Test an arbitrary sequence-consistency bug encountered during speed test'''
    tokens = EN(u'Where rap essentially went mainstream, illustrated by seminal Public Enemy, Beastie Boys and L.L. Cool J. tracks.')
    tokens = EN(u'''Charity and other short-term aid have buoyed them so far, and a tax-relief bill working its way through Congress would help. But the September 11 Victim Compensation Fund, enacted by Congress to discourage people from filing lawsuits, will determine the shape of their lives for years to come.\n\n''', disable=['ner'])
    tokens.ents += tuple(EN.matcher(tokens))
    EN.entity(tokens)


@pytest.mark.skip
@pytest.mark.models('en')
def test_en_ner_unit_end_gazetteer(EN):
    '''Test a bug in the interaction between the NER model and the gazetteer'''
    matcher = Matcher(EN.vocab)
    matcher.add('MemberNames', None, [{LOWER: 'cal'}], [{LOWER: 'cal'}, {LOWER: 'henderson'}])
    doc = EN(u'who is cal the manager of?')
    if len(list(doc.ents)) == 0:
        ents = matcher(doc)
        assert len(ents) == 1
        doc.ents += tuple(ents)
        EN.entity(doc)
        assert list(doc.ents)[0].text == 'cal'



from __future__ import unicode_literals

from ...symbols import POS, ADV, NOUN, ADP, PRON, SCONJ, PROPN, DET, SYM, INTJ
from ...symbols import PUNCT, NUM, AUX, X, CONJ, ADJ, VERB, PART, SPACE, CCONJ



TAG_MAP = {
	"ADJ": {POS: ADJ},
	"ADV": {POS: ADV},
	"INTJ": {POS: INTJ},
	"NOUN": {POS: NOUN},
	"PROPN": {POS: PROPN},
	"VERB": {POS: VERB},
	"ADP": {POS: ADP},
	"CCONJ": {POS: CCONJ},
	"SCONJ": {POS: SCONJ},
	"PART": {POS: PART},
	"PUNCT": {POS: PUNCT},
	"SYM": {POS: SYM},
	"NUM": {POS: NUM},
	"PRON": {POS: PRON},
	"AUX": {POS: AUX},
	"SPACE": {POS: SPACE},
	"DET": {POS: DET},
	"X" : {POS: X}
}
